@@ -47,7 +47,8 @@ def writefile_cor(prefixfilename, twicetheta, chi, data_x, data_y, dataintensity
                                                                             data_sat=None,
                                                                             data_props=None,
                                                                             rectpix=0,  # RECTPIX
-                                                                            dirname_output=None):
+                                                                            dirname_output=None,
+                                                                            verbose=0):
     """
     Write .cor file containing data
     one line   of header
@@ -131,7 +132,7 @@ def writefile_cor(prefixfilename, twicetheta, chi, data_x, data_y, dataintensity
         outputfile.write("\n# From: %s" % initialfilename)
 
     # metadata on detector position and nature
-    print(' param   in writefile_cor() for prefixfilename %s'%prefixfilename, param)
+    if verbose: print(' param   in writefile_cor() for prefixfilename %s'%prefixfilename, param)
     if param is not None:
         outputfile.write("\n# Calibration parameters")
         # param is a list
@@ -148,7 +149,7 @@ def writefile_cor(prefixfilename, twicetheta, chi, data_x, data_y, dataintensity
                 raise ValueError("5 or 6 calibration parameters are needed!")
         # param is a dict : CCDCalibdict
         elif isinstance(param, dict):
-            print("param is a dict!")
+            if verbose: print("param is a dict!")
             for key in CCD_CALIBRATION_PARAMETERS:
                 # print('key in CCD_CALIBRATION_PARAMETERS', key)
                 if key in param:
@@ -1325,7 +1326,7 @@ def read3linesasMatrix(fileobject):
                 val = float(elem)
                 listelem.append(val)
 
-        print("listelem", listelem)
+        #print("listelem", listelem)
 
         matrix[i, :] = np.array(listelem, dtype=float)
         iline += 1
@@ -1419,7 +1420,7 @@ def readListofMatrices(fullpathtoFile):
     if (nbElements % 9) != 0:
         raise ValueError("Number of elements is not a multiple of 9")
 
-    nbMatrices = nbElements / 9
+    nbMatrices = nbElements // 9
     matrices = np.array(listelem, dtype=float).reshape((nbMatrices, 3, 3))
     return nbMatrices, matrices
 
@@ -1570,7 +1571,7 @@ def readCheckOrientationsFile(fullpathtoFile):
         if line.startswith("$"):
             if line.startswith("$FileIndex"):
                 line = str(f.readline())
-                print("$FileIndex: ", line)
+                #print("$FileIndex: ", line)
                 list_indices = getfileindex(line)
                 Current_CheckOrientationParameters[0] = list_indices
                 known_values[0] = True
@@ -1606,19 +1607,18 @@ def readCheckOrientationsFile(fullpathtoFile):
                 lineindex += 1
             elif line.startswith("$Matrix"):
                 nbMatrices, matrices, nblines, posfile = readdataasmatrices(f)
-                print("nbMatrices,matrices, nblines, posfile",
-                    nbMatrices,
-                    matrices,
-                    nblines,
-                    posfile)
+                #print("nbMatrices,matrices, nblines, posfile",
+                    # nbMatrices,
+                    # matrices,
+                    # nblines,
+                    # posfile)
 
                 Current_CheckOrientationParameters[5] = matrices
                 known_values[5] = True
                 List_posMatrices.append(lineindex)
 
-                print("Current_CheckOrientationParameters",
-                    Current_CheckOrientationParameters)
-                print("known_values", known_values)
+                #print("Current_CheckOrientationParameters", Current_CheckOrientationParameters)
+                #print("known_values", known_values)
 
                 List_CheckOrientations.append(copy.copy(Current_CheckOrientationParameters))
 
@@ -1635,12 +1635,12 @@ def readCheckOrientationsFile(fullpathtoFile):
 
 
 def getfileindex(str_expression):
-    print("str_expression", str_expression)
+    #print("str_expression", str_expression)
     if str_expression.strip() in ("all", "All"):
         return -1
 
     list_val = str_expression.strip("[]()\n").split(",")
-    print("list_val", list_val)
+    #print("list_val", list_val)
     integerlist = [int(float(elem)) for elem in list_val]
     return integerlist
 
@@ -1657,7 +1657,7 @@ def readdataasmatrices(fileobject):
 
     while True:
         line = str(fileobject.readline())
-        print("line matrix", line)
+        #print("line matrix", line)
         if line.startswith("$"):
             break
         if line.strip() in ("END",):
